
package com.ibm.tools.attach;

/*
 * Licensed Materials - Property of IBM,
 *     Copyright IBM Corp. 2009, 2010  All Rights Reserved
 */
import com.ibm.tools.attach.spi.AttachProvider;

/**
 * Contains the information about a target VM
 *
 * This class is analogous to and intended to be compatible with
 * com.sun.tools.attach.VirtualMachineDescriptor.
 *
 * @see "http://w3.hursley.ibm.com/java/docs/java7/jdk/api/attach/spec/com/sun/tools/attach/VirtualMachineDescriptor.html"
 */
public class VirtualMachineDescriptor {

	private String id;
	private String displayName;
	private AttachProvider provider;

	/**
	 * @param provider
	 *            AttachProvider associated with this VM
	 * @param id
	 *            VM identifier (for machine use)
	 * @note Public API, signature compatible with
	 *       com.sun.tools.attach.spi.AttachProvider.
	 */
	public VirtualMachineDescriptor(AttachProvider provider, String id) {
		this(provider, id, id);
	}

	/**
	 * @param provider
	 *            AttachProvider associated with this VM
	 * @param id
	 *            VM identifier (for machine use)
	 * @param name
	 *            VM name for human use
	 * @note Public API, signature compatible with
	 *       com.sun.tools.attach.spi.AttachProvider.
	 */
	public VirtualMachineDescriptor(AttachProvider provider, String id,
			String name) {
		this.provider = provider;
		this.id = id;
		this.displayName = (null == name)? id: name;
		if ((null == provider) || (null == id)) {
			// K0554 = Virtual machine ID or display name is null
			throw new NullPointerException(com.ibm.oti.util.Msg.getString("K0554")); //$NON-NLS-1$
		}
	}

	/**
	 * @return VM name
	 * @note Public API, signature compatible with
	 *       com.sun.tools.attach.spi.AttachProvider.
	 */
	public String displayName() {
		return displayName;
	}

	/**
	 * @return True if the VirtualMachineDescriptor is equivalent to comparand.
	 */
	public boolean equals(Object comparand) {

		if (comparand == null) {
			return false;
		}

		if (comparand.getClass() != this.getClass()) {
			return false;
		}

		VirtualMachineDescriptor desc = (VirtualMachineDescriptor) comparand;
		if (desc.provider() != provider) {
			return false;
		}

		return id.equals(desc.id());
	}

	/**
	 *
	 * @note Public API, signature compatible with
	 *       com.sun.tools.attach.spi.AttachProvider.
	 */
	public int hashCode() {
		return id.hashCode();
	}

	/**
	 * @return VM ID
	 * @note Public API, signature compatible with
	 *       com.sun.tools.attach.spi.AttachProvider.
	 */
	public String id() {
		return id;
	}

	/**
	 * @return AttachProvider associated with this VM
	 * @note Public API, signature compatible with
	 *       com.sun.tools.attach.spi.AttachProvider.
	 */
	public AttachProvider provider() {
		return provider;
	}

	/**
	 *
	 * @note Public API, signature compatible with
	 *       com.sun.tools.attach.spi.AttachProvider.
	 */
	@Override
	public String toString() {
		return id + '\n' + displayName + '\n';
	}
}
